@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# Copyright (C) 2011-19 Dr. Ralf Schlatterbeck Open Source Consulting.
+# Copyright (C) 2011-21 Dr. Ralf Schlatterbeck Open Source Consulting.
 # Reichergasse 131, A-3411 Weidling.
 # Web: http://www.runtux.com Email: office@runtux.com
 # All rights reserved
@@ -33,7 +33,7 @@ def ascii (s) :
     return s
 # end def ascii
 
-def hexdump (s, start = 0, show_addr = True) :
+def hexdump (s, start = 0, show_addr = True, last_addr = True) :
     """
     >>> a = b'1234567890abcdefghijklmnopqrstuv'
     >>> print (hexdump (a + b'\\xce\\x02\\xb9\x49', show_addr = False))
@@ -48,18 +48,20 @@ def hexdump (s, start = 0, show_addr = True) :
     assert isinstance (s, type (b''))
     r = []
     for x in range (len (s) // 16 + 1) :
+        slc  = s [x*16:(x+1)*16]
         adr  = '%08x'  % (start + x * 16)
         hex  = '%-48s' % ' '.join \
-            ("%02x" % bytes_ord (k) for k in s [x*16:(x+1)*16])
-        char = '%-16s' % ''.join (ascii (k) for k in s [x*16:(x+1)*16])
+            ("%02x" % bytes_ord (k) for k in slc)
+        char = '%-16s' % ''.join (ascii (k) for k in slc)
         vars = (adr, hex, char)
         if not show_addr :
             vars = (hex, char)
-        r.append ('  '.join (vars))
+        if last_addr or slc :
+            r.append ('  '.join (vars))
     return '\n'.join (r)
 # end def hexdump
 
-def unhexdump (iterable) :
+def unhexdump (iterable, file = None) :
     """ Convert a hex-dump to binary
     """
     bin = []
@@ -71,7 +73,7 @@ def unhexdump (iterable) :
         if end :
             raise ValueError ("Unknown hexdump format")
         x = line.split ('  ', 2)
-        if len (x) <= 2 :
+        if len (x) == 1 :
             h = x [0]
         else :
             h = x [1]
@@ -87,6 +89,12 @@ def unhexdump (iterable) :
             method = lambda x : b''.join (chr (c) for c in x)
         else :
             method = bytes
-        bin.append (method ((int (k, 16)) for k in h))
+        if file :
+            file.write (method ((int (k, 16)) for k in h))
+        else :
+            bin.append (method ((int (k, 16)) for k in h))
+    if file :
+        file.flush ()
+        return None
     return b''.join (bin)
 # end def unhexdump
