@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # test exec framework for multi-pipe
 import time
 from rsclib.execute import exitstatus, Method_Process, Exec_Process
@@ -30,4 +30,4 @@ p1.wait ()
 
 for p in (p1, p2, p3, p4) :
     if p.status :
-        print exitstatus (p.name, p.status)
+        print (exitstatus (p.name, p.status))
